@@ -3,16 +3,17 @@
 # appends "missing" columns with missingness indicator
 setGeneric("fill.missing", function(x, seed=101, ...) standardGeneric("fill.missing"))
 setMethod("fill.missing", "data.frame", function(x, seed=101, ...) {
+    if(exists(".Random.seed", envir = .GlobalEnv)) {
+        save.seed <- get(".Random.seed", envir= .GlobalEnv)
+        on.exit(assign(".Random.seed", save.seed, envir = .GlobalEnv))
+    } else {
+        on.exit(rm(".Random.seed", envir = .GlobalEnv))
+    }
     miss.cols <- which(apply(x, MARGIN=2, FUN=function(y) { xm<-is.na(y);(any(xm) & !all(xm))}))
     if(length(miss.cols) > 0) {
         missingness <- data.frame(is.na(x[,miss.cols])+0)
         names(missingness) <- sprintf("%s.missing", names(x)[miss.cols])
     }
-    restoreRandom <- FALSE
-    if(exists(".Random.seed")) {
-        save.seed <- .Random.seed
-        restoreRandom <- TRUE
-    }
     if(!is.numeric(seed)) seed <- 101
     set.seed(seed)
     fmla <- as.formula(paste("~", paste(names(x), collapse= "+")))
@@ -29,7 +30,5 @@ setMethod("fill.missing", "data.frame", function(x, seed=101, ...) {
             x[names(imputed.vals), cname] <<- imputed.vals
         }
     }))
-    if(restoreRandom) .Random.seed <<- save.seed
-    else rm(.Random.seed, inherits=TRUE)
     cbind(x, missingness)
 })
