@@ -435,7 +435,7 @@ C
  9001	  NC	    =CC(I3)
 	  D	    =DFLOAT(NC)-Y1(NB1)-Y1(NB2)
 	  D	    =D-Y2(N1)-Y2(N2)
-      IF (DABS(D).GT.EPS)     WRITE(6,7000) N1,N2,D
+      IF (DABS(D).GT.EPS)     CALL RPRINT(N1,N2,D)
 	  ZFW	    =ZFW+NC
   702 CONTINUE
       DO 750	  N1=1,N
@@ -486,7 +486,7 @@ C
  9003	  NC	    =CC(I3)
 	  D	    =DFLOAT(NC)-Y1(NB1)-Y1(NB2)
 	  D	    =D-Y2(NK1)-Y2(NK2)
-      IF (DABS(D).GT.EPS)     WRITE(6,7000) NK1,NK2,D
+      IF (DABS(D).GT.EPS)     CALL RPRINT(NK1,NK2,D)
 	  ZFW	    =ZFW+NC
       IF (NB1.NE.NB)			GOTO 735
   740 IF (NB3.EQ.NB)			GOTO 705
@@ -501,7 +501,7 @@ C
  9005	  NC	    =CC(I3)
 	  D	    =DFLOAT(NC)-Y1(NB2)-Y1(NB3)
 	  D	    =D-Y2(N2)-Y2(N3)
-      IF (DABS(D).GT.EPS)     WRITE(6,7000) N2,N3,D
+      IF (DABS(D).GT.EPS)     CALL RPRINT(N2,N3,D)
 	  ZFW	    =ZFW+NC
 	  N3	    =TMA(NB2)
 	  NB3	    =BASIS(N3)
@@ -519,6 +519,16 @@ C
      *   /1H ,8X,6HEDGE (,I3,1H,,I3,1H),5X,F15.4)
 C
       END
+C
+      SUBROUTINE RPRINT(A,B,D)
+      CHARACTER(55) OUTPUT
+      INTEGER A,B
+      DOUBLE PRECISION D
+      OUTPUT='0ERROR , THE OPTIMALITY CONDITIONS ARE VIOLATED AT EDGE'
+      CALL INTPR(OUTPUT, 55, [A,B], 2)
+      CALL DBLEPR(OUTPUT, 0, D, 1)
+      END
+C
       SUBROUTINE SCAN1(NB1,N,SUP,CC,BASIS,MEM,KA,KB,SM,TMA,TMB,
      *			Y1,Y2,DPLUS,DMINUS,NBL,INDEX)
       INTEGER	 N,TOP
